@@ -270,7 +270,6 @@ class BaseValidationTask(
             - ``<kwarg_*>`` is the name of a keyword argument passed to the constructor of the
               required task.
         """
-        # pylint: disable=no-self-use
         return None
 
     def args(self):
@@ -279,7 +278,6 @@ class BaseValidationTask(
         This method can be overridden to pass these arguments to the :meth:`validation_function`
         and to the :meth:`pre_process` and :meth:`post_process` methods.
         """
-        # pylint: disable=no-self-use
         return []
 
     def kwargs(self):
@@ -289,7 +287,6 @@ class BaseValidationTask(
         :meth:`validation_function` and to the :meth:`pre_process` and
         :meth:`post_process` methods.
         """
-        # pylint: disable=no-self-use
         return {}
 
     def read_dataset(self):
@@ -300,6 +297,15 @@ class BaseValidationTask(
         """
         return pd.read_csv(self.dataset_df, index_col=self.input_index_col)
 
+    def transform_index(self, df):
+        """Method executed after loading the dataset to transform its index.
+
+        .. note::
+
+            This transformation is applied to both the dataset and the input reports.
+        """
+        return df
+
     def pre_process(self, df, args, kwargs):
         """Method executed before applying the external function."""
 
@@ -356,7 +362,6 @@ class BaseValidationTask(
 
     def extra_requires(self):
         """Requirements that should not be considered as validation tasks."""
-        # pylint: disable=no-self-use
         return []
 
     def extra_input(self):
@@ -444,6 +449,7 @@ class BaseValidationTask(
         if self.dataset_df is not None:
             L.info("Input dataset: %s", Path(self.dataset_df).resolve())
             new_df = self.read_dataset()
+            new_df = self.transform_index(new_df)
             duplicated_index = new_df.index.duplicated()
             if duplicated_index.any():
                 raise IndexError(
@@ -477,8 +483,10 @@ class BaseValidationTask(
             }
             L.debug("Importing the following reports: %s", all_report_paths)
             all_dfs = {
-                task_obj: self._rename_cols(
-                    pd.read_csv(path, index_col=INDEX_LABEL).rename_axis(index="index")
+                task_obj: self.transform_index(
+                    self._rename_cols(
+                        pd.read_csv(path, index_col=INDEX_LABEL).rename_axis(index="index")
+                    )
                 )
                 for task_obj, path in all_report_paths.items()
             }
@@ -699,7 +707,7 @@ class SetValidationTask(BaseValidationTask):
         return df
 
 
-class ValidationWorkflow(SetValidationTask):
+class ValidationWorkflow(SetValidationTask, luigi.WrapperTask):
     """Class to define and process a validation workflow."""
 
     report_path = OptionalStrParameter(
@@ -794,7 +802,6 @@ def SkippableMixin(default_value=False):
         skip = BoolParameter(default=default_value, description=":bool: Skip the task")
 
         def __init__(self, *args, **kwargs):
-
             super().__init__(*args, **kwargs)
 
             if isinstance(self, ElementValidationTask):
